# Data

This directory contains two files. The first, `trace.zip` is a sample memory trace generated from tracing the `true` command. This has been compressed to save space, but it should be unzipped before passing it to `memtrace2npz`. The second file, `gold.nzp` is the expected output of running `memtrace2npz` on the unzipped contents of `trace.zip`.
